# Copyright (c) 2010, 2011 Linaro
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import os, re

from tests.imposters import ConfigImposter, OutputImposter
from tests.fixtures import TestCaseWithFixtures
from lava_test.main import LAVATestDispatcher

class LavaTestCommandTestCase(TestCaseWithFixtures):
    def setUp(self):
        self.config = self.add_fixture(ConfigImposter())
        self.out = self.add_fixture(OutputImposter())

    def _runLavaTest(self, cmds):
        LAVATestDispatcher().dispatch(cmds)

class BadCommand(LavaTestCommandTestCase):
    def test_bad_cmd(self):
        # Running an unknown command that does not exist of a command that does
        # gives a nice error message.
        errmsg = "invalid choice: 'results'"

        self.assertRaises(SystemExit, LAVATestDispatcher().dispatch, ['results', 'foo'])
        self.assertNotEqual(None, re.search(errmsg, self.out.getvalue()), re.MULTILINE)
        self.assertTrue(errmsg in self.out.getvalue())

class ListKnown(LavaTestCommandTestCase):
    def test_list_tests(self):
        self._runLavaTest(['list-tests'])
        self.assertTrue("stream" in self.out.getvalue())

class ListInstalled(LavaTestCommandTestCase):
    def test_list_installed(self):
        # test_name must be in the BuiltInProvider._builtin_tests
        test_name="ltp"
        os.makedirs(os.path.join(self.config.installdir, test_name))
        self._runLavaTest(['list-installed'])
        self.assertTrue(test_name in self.out.getvalue())

    def test_run_command_test_not_exist(self):
        self._runLavaTest(['run','abc'])
        self.assertTrue("There is no test with the specified ID" in self.out.getvalue())

class TestHelp(LavaTestCommandTestCase):

    def test_command_help(self):
        self.assertRaises(SystemExit, LAVATestDispatcher().dispatch, ['--help'])
        self.assertTrue("--help" in self.out.getvalue())

