# Copyright (c) 2010, 2011 Linaro
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import re

from lava_test.core.installers import TestInstaller
from lava_test.core.tests import Test
from lava_test.core.runners import TestRunner
from tests.imposters import OutputImposter, ConfigImposter
from tests.fixtures import TestCaseWithFixtures

def maketest(name="foo", version="", installer=None, runner=None, parser=None):
    if installer is None:
        installer = makeinstaller()
    return Test(name, version, installer, runner, parser)

def makerunner(**kwargs):
    return TestRunner(**kwargs)

def makeinstaller(**kwargs):
    return TestInstaller(**kwargs)

class TestConfigOutput(TestCaseWithFixtures):
    def setUp(self):
        super(TestConfigOutput, self).setUp()
        self.config = self.add_fixture(ConfigImposter())
        
    def test_run(self):
        testrunner = makerunner(steps=["echo foo"])
        test = maketest(name="foo", runner=testrunner)
        
        self.assertFalse(test.is_installed)
        test.install()
        self.assertTrue(test.is_installed)
        artifacts = test.run()
        std_out = open(artifacts.stdout_pathname).read()
        self.assertTrue("foo" in std_out)

        result_id_pattern = "foo\.\d{4}-\d{2}-\d{2}T\d{2}:\d{2}:\d{2}Z"
        self.assertTrue(re.match(result_id_pattern, artifacts.result_id))

        test.uninstall()
        self.assertFalse(test.is_installed)
