# Copyright (c) 2010, 2011 Linaro
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import os
import shutil
import tempfile
import unittest
from datetime import datetime

from lava_test.core.runners import TestRunner
from lava_test.core.artifacts import TestArtifacts
from tests.imposters import OutputImposter, ConfigImposter
from tests.fixtures import TestCaseWithFixtures

def makerunner(**kwargs):
    return TestRunner(**kwargs)
 
class testTestRunner(TestCaseWithFixtures):
    def setUp(self):
        self.config = self.add_fixture(ConfigImposter())
        self.out = self.add_fixture(OutputImposter())
        self.origdir = os.path.abspath(os.curdir)
        self.tmpdir = tempfile.mkdtemp()
        self.filename = os.path.abspath(__file__)
        os.chdir(self.tmpdir)
        self.test_id = "ABC"
        self.artifacts = TestArtifacts.allocate(self.test_id, self.config)

    def tearDown(self):
        os.chdir(self.origdir)
        shutil.rmtree(self.tmpdir)

    def test_starttime(self):
        runner = makerunner()
        runner.run(self.artifacts)
        self.assertTrue(isinstance(runner.starttime, datetime))

    def test_endtime(self):
        runner = makerunner()
        runner.run(self.artifacts)
        self.assertTrue(isinstance(runner.endtime, datetime))

    def test_timediff(self):
        steps = ['sleep 2']
        runner = makerunner(steps=steps)
        runner.run(self.artifacts)
        self.assertNotEqual(runner.starttime, runner.endtime)

    def test_runsteps(self):
        steps = ["echo test > foo"]
        runner = makerunner(steps=steps)
        runner._run_lava_test_steps(self.artifacts, observer = None)
        self.assertTrue(os.path.exists("./foo"))

    def test_logoutput(self):
        steps = ["echo test > foo"]
        runner = makerunner(steps=steps)
        runner._run_lava_test_steps(self.artifacts, observer = None)
        self.assertTrue(os.path.exists(self.artifacts.stdout_pathname))
        self.assertTrue(os.path.exists(self.artifacts.stderr_pathname))
        
